@@ -1,90 +1,101 @@
+if(getRversion() >= "2.15.1")
+  utils::globalVariables(c("L", "R_mat", "m", "indicies_fix", "id", "Q_0",
+                           ".F", "Q", "model"))
+
 #' @title Bootstrap for \code{\link{ddhazard}}
-#' @param ddhazard_fit Returned object from a \code{\link{ddhazard}} call
-#' @param strata Strata to sample within. These need to be on an individual by individual basis and not rows in the design matrix
-#' @param unique_id Unique ids where entries match entries of \code{strata}
-#' @param R Number of bootstrap estimates
-#' @param do_stratify_with_event \code{TRUE} if sampling should be by strata of whether the individual has an event. An interaction factor will be made if \code{strata} is provided
-#' @param do_sample_weights \code{TRUE} if weights should be sample instead of individuals
-#' @param LRs Learning rates in decreasing order which will be used to estimate the model.
-#' @param print_errors \code{TRUE} if errors should be printed when estimations fails
+#' @param ddhazard_fit returned object from a \code{\link{ddhazard}} call.
+#' @param strata strata to sample within. These need to be on an individual by individual basis and not rows in the design matrix.
+#' @param unique_id unique ids where entries match entries of \code{strata}.
+#' @param R number of bootstrap estimates.
+#' @param do_stratify_with_event \code{TRUE} if sampling should be by strata of whether the individual has an event. An interaction factor will be made if \code{strata} is provided.
+#' @param do_sample_weights \code{TRUE} if weights should be sampled instead of individuals.
+#' @param LRs learning rates in decreasing order which will be used to estimate the model.
+#' @param print_errors \code{TRUE} if errors should be printed when estimations fails.
 #'
 #' @description
-#' See the vignette 'Bootstrap illustration'. The \code{do_stratify_with_event} may be useful when either cases or non-cases are very rare to ensure that the model estimation succeeds.
+#' See the vignette \code{vignette("Bootstrap_illustration", "dynamichazard")}. The \code{do_stratify_with_event} may be useful when either cases or non-cases are very rare to ensure that the model estimation succeeds.
 #'
 #' @return
-#' An object like returned from the \code{\link[boot]{boot}} function
+#' An object like from the \code{\link[boot]{boot}} function.
 #'
 #' @seealso
-#' \code{\link{ddhazard}}, \code{\link[=plot.fahrmeier_94]{plot}}
+#' \code{\link{ddhazard}}, \code{\link[=plot.ddhazard]{plot}}
+#'
+#'
+#' @examples
+#'\dontrun{
+#'library(dynamichazard)
+#'set.seed(56219373)
+#'fit <- ddhazard(
+#'  Surv(time, status == 2) ~ log(bili), pbc, id = pbc$id, max_T = 3000,
+#'  Q_0 = diag(1, 2), Q = diag(1e-4, 2), by = 100,
+#'  control = list(method = "GMA"))
+#'bt <- ddhazard_boot(fit, R = 999)
+#'plot(fit, ddhazard_boot = bt, level = .9)
+#'}
 #'
 #' @export
-ddhazard_boot <- function(ddhazard_fit,  strata, unique_id, R = 100,
-                          do_stratify_with_event = F, do_sample_weights = F,
-                          LRs = ddhazard_fit$control$LR * 2^(0:(-4)), print_errors = F){
+ddhazard_boot <- function(
+  ddhazard_fit,  strata, unique_id, R = 100,
+  do_stratify_with_event = F, do_sample_weights = F,
+  LRs = ddhazard_fit$control$LR * 2^(0:(-4)), print_errors = F){
   if(is.unsorted(-LRs, strictly = T) && any(LRs <=0))
     stop("LRs need to be stricly decreasing postive numbers")
 
   if(is.null(ddhazard_fit$risk_set) || is.null(ddhazard_fit$data))
     stop("Cannot bootstrap estimates when ddhazard has been called with control = list(save_risk_set = F, save_data = F, ...)")
 
-  id <- ddhazard_fit$id
-  X_Y <- get_design_matrix(formula = ddhazard_fit$formula, data = ddhazard_fit$data)
+  list2env(ddhazard_fit[c("control", "id", "data", "order", "model")],
+           environment())
+  X_Y <- get_design_matrix(
+    data = data, Terms = ddhazard_fit$terms, xlev = ddhazard_fit$xlev,
+    has_fixed_intercept = ddhazard_fit$has_fixed_intercept)
 
-  # Find unique id and whether the individuals do die
+  # find unique ids and whether the individuals do die
   if(missing(unique_id))
     unique_id <- unique(id)
 
   if(missing(strata)){
     strata <- as.factor(rep(1, length(unique_id)))
+
   } else if(!is.factor(strata))
     strata <- as.factor(strata)
 
   if(length(strata) != length(unique_id)){
     stop("The strata argument should have same length as the unique ids")
+
   }
   if(do_stratify_with_event){
     is_event <- as.factor(tapply(ddhazard_fit$risk_set$is_event_in, id,
                                  function(x) sum(x > -1) == 1))
     strata <- interaction(strata, is_event, drop = T)
+
   }
 
-  # Change starting value for fixed effects
-  ddhazard_fit$control$fixed_parems_start <- ddhazard_fit$fixed_effects
+  # change starting value for fixed effects
+  control$fixed_parems_start <- ddhazard_fit$fixed_effects
 
-  # Define indicies for fixed effects in the state space vector
+  # define indicies for fixed effects in the state space vector
   n_fixed <- ncol(X_Y$fixed_terms)
-  n_varying <- ncol(ddhazard_fit$state_vecs)/ddhazard_fit$order
+  n_varying <- ncol(ddhazard_fit$state_vecs)/order
   n_periods <- nrow(ddhazard_fit$state_vecs)
   n_out <- n_fixed +                           # number of parameters returned
-    n_varying * n_periods * ddhazard_fit$order # by statistic function
+    n_varying * n_periods * order              # by statistic function
 
-  # We need to make adjustments if fixed effects are estimated in the E-step
-  a_0 <- ddhazard_fit$state_vecs[1,]
-  if(ddhazard_fit$control$fixed_terms_method == "E_step" &&
-     n_fixed > 0){
-    indicies_fixed_coef_in_state <- 1:n_fixed +  n_varying
-
-    # We need to add indicies to Q
-    Q_new <- ddhazard_fit$Q_0 # This has the right dimension
-    Q_new[,] <- 0
-    Q_new[1:n_varying, 1:n_varying] <- ddhazard_fit$Q
-    ddhazard_fit$Q <- Q_new
-
-    # We need the right F matrix
-    ddhazard_fit$F_ <-  get_F(
-      ddhazard_fit$order, n_varying, n_fixed, T)
-
-    # and to a_0
-    if(ddhazard_fit$order == 1){
-      a_0 <- c(a_0, ddhazard_fit$control$fixed_parems_start)
-    } else if(ddhazard_fit$order == 2){
-      first_half <- 1:(length(a_0)/2)
-      a_0 <-
-        c(a_0[first_half], ddhazard_fit$control$fixed_parems_start, a_0[-first_half])
-    } else
-      stop("Method not implemented for order equal to ", ddhazard_fit$order)
-  } else
-    indicies_fixed_coef_in_state <- vector()
+  #####
+  # Find matrices for state equation
+  est_fixed_in_E <-
+    control$fixed_terms_method == "E_step" && n_fixed > 0
+  a_0 <- ddhazard_fit$state_vecs[1, ]
+  tmp <- get_state_eq_matrices(
+    order =  order, n_params = n_varying, n_fixed = n_fixed,
+    est_fixed_in_E = est_fixed_in_E,
+    Q_0 = ddhazard_fit$Q_0,
+    Q = ddhazard_fit$Q,
+    a_0 = a_0, control)
+  names(tmp)[names(tmp) == "R"] <- "R_mat" # re-name to not remove present R
+                                           # object
+  list2env(tmp, environment())
 
   # Define function for boot
   statistic <- function(data, ran.gen){
@@ -100,34 +111,32 @@ ddhazard_boot <- function(ddhazard_fit,  strata, unique_id, R = 100,
       included_ids <- as.numeric(included_ids)
     which_rows_are_included <- which(id %in% included_ids)
 
-    # Adjust weights vector
+    # adjust weights vector
     ws <- ws[match(id[which_rows_are_included], included_ids)]
 
-    # Adjust X_Y
+    # adjust X_Y
     boot_X_Y <- X_Y
-    for(el_name in c("X", "fixed_terms", "Y")){
-      boot_X_Y[[el_name]] <- boot_X_Y[[el_name]][which_rows_are_included, , drop = F]
-    }
+    for(el_name in c("X", "fixed_terms", "Y"))
+      boot_X_Y[[el_name]] <- boot_X_Y[[el_name]][
+        which_rows_are_included, , drop = F]
 
-    # Adjust risk set
+    # adjust risk set
     boot_risk_set <- ddhazard_fit$risk_set
     boot_risk_set$is_event_in <-
       boot_risk_set$is_event_in[which_rows_are_included]
 
-    # Permutate if done on the first fit
-    if(ddhazard_fit$control$permu){
+    # permutate if done on the first fit
+    if(control$permu)
       eval(get_permu_data_exp(boot_X_Y[1:3], boot_risk_set, ws))
-    }
 
-    # Add fixed terms to design matrix if fixed terms are estimated in the
+    # add fixed terms to design matrix if fixed terms are estimated in the
     # E-step
-    if(ddhazard_fit$control$fixed_terms_method == "E_step" &&
-       n_fixed > 0){
+    if(control$fixed_terms_method == "E_step" && n_fixed > 0){
       boot_X_Y$X <- cbind(boot_X_Y$X, boot_X_Y$fixed_terms)
       boot_X_Y$fixed_terms <- matrix(nrow = nrow(boot_X_Y$X), ncol = 0)
     }
 
-    # Transpose due to column-major ordering in c++
+    # transpose due to column-major ordering in c++
     boot_X_Y$X <- t(boot_X_Y$X)
     boot_X_Y$fixed_terms <- t(boot_X_Y$fixed_terms)
 
@@ -142,27 +151,27 @@ ddhazard_boot <- function(ddhazard_fit,  strata, unique_id, R = 100,
         index_map[match(tmp, index_map[,'old_index']), 'new_index']
     }
 
-    # Estimate and return state vectors
+    # estimate and return state vectors
     est <- NULL
     did_succed <- FALSE
     for(l in LRs){
       tryCatch({
         suppressWarnings(est <- ddhazard_no_validation(
-          a_0 = a_0, Q_0 = ddhazard_fit$Q_0,
-          .F = ddhazard_fit$F_, verbose = F, Q = ddhazard_fit$Q,
+          a_0 = a_0, Q_0 = Q_0, L = L, R = R_mat, m = m,
+          .F = .F, verbose = F, Q = Q,
           risk_set= boot_risk_set, X_Y = boot_X_Y,
-          order = ddhazard_fit$order, model = ddhazard_fit$model,
+          model = model,
           LR = l,
           n_fixed_terms_in_state_vec =
-            ifelse(ddhazard_fit$control$fixed_terms_method == "E_step", n_fixed, 0),
+            if(control$fixed_terms_method == "E_step") n_fixed else 0,
           weights = ws,
-          control = ddhazard_fit$control))
+          control = control))
 
-        out <- c(est$a_t_d_s[, !seq_len(ncol(est$a_t_d_s)) %in% indicies_fixed_coef_in_state])
+        out <- c(est$a_t_d_s[, !seq_len(ncol(est$a_t_d_s)) %in% indicies_fix])
         if(n_fixed > 0){
-          if(ddhazard_fit$control$fixed_terms_method == "E_step")
-            out <- c(out, est$a_t_d_s[1, indicies_fixed_coef_in_state]) else
-              out <- c(out, est$fixed_effects)
+          out <- if(control$fixed_terms_method == "E_step")
+            c(out, est$a_t_d_s[1, indicies_fix]) else
+              c(out, est$fixed_effects)
         }
         did_succed <- TRUE
         est <- out
@@ -182,8 +191,7 @@ ddhazard_boot <- function(ddhazard_fit,  strata, unique_id, R = 100,
     est
   }
 
-
-  # Bootstrap estimates
+  # bootstrap
   data <- rep(1, length(unique_id))
   names(data) <- unique_id
   boot_est <-
@@ -217,7 +225,8 @@ ddhazard_boot <- function(ddhazard_fit,  strata, unique_id, R = 100,
   class(boot_est) <- c("ddhazard_boot", class(boot_est))
   boot_est$t_names <-
     c(c(sapply(colnames(ddhazard_fit$state_vecs),
-               function(x) paste(x, 1:nrow(ddhazard_fit$state_vecs) - 1, sep = ":t"))),
+               function(x)
+                 paste(x, 1:nrow(ddhazard_fit$state_vecs) - 1, sep = ":t"))),
       names(ddhazard_fit$fixed_effects))
 
   colnames(boot_est$t) <- boot_est$t_names
@@ -229,7 +238,7 @@ ddhazard_boot <- function(ddhazard_fit,  strata, unique_id, R = 100,
 
 get_frac_n_weights <- function(R, a){
   #####
-  # Function to make linear interpolation with weights from normal density
+  # function to make linear interpolation with weights from normal density
 
   k <- floor((R + 1) * a)
   if(k == 0 || k == R)
@@ -241,4 +250,3 @@ get_frac_n_weights <- function(R, a){
 
   list(k = k, w_k = w_k, w_k_p_1 = w_k_p_1)
 }
-
